@@ -2,15 +2,16 @@
 import logging
 
 from pyage.core import address
-from pyage.core.agent.agent import   generate_agents, Agent
-from pyage.core.locator import Pyro4Locator, ParentLocator
-from pyage.core.migration import  NoMigration
-from pyage.core.statistics import  NoStatistics
+
+from pyage.core.agent.agent import generate_agents, Agent
+from pyage.core.locator import ParentLocator
+from pyage.core.migration import NoMigration
+from pyage.core.statistics import NoStatistics
 from pyage.core.stop_condition import StepLimitStopCondition
-from pyage.solutions.evolution.crossover import  AverageFloatCrossover
-from pyage.solutions.evolution.evaluation import  FloatRastriginEvaluation
-from pyage.solutions.evolution.initializer import  FloatInitializer
-from pyage.solutions.evolution.mutation import  UniformFloatMutation
+from pyage.solutions.evolution.crossover import AverageFloatCrossover
+from pyage.solutions.evolution.evaluation import FloatRastriginEvaluation
+from pyage.solutions.evolution.initializer import FloatInitializer
+from pyage.solutions.evolution.mutation import UniformFloatMutation
 from pyage.solutions.evolution.selection import TournamentSelection
 
 logger = logging.getLogger(__name__)
