@@ -1,14 +1,19 @@
 import logging
-from Pyro4 import locateNS
 from pyage.core.address import Addressable
-from inject import Inject, InjectOptional
+from pyage.core.inject import Inject, InjectOptional
 from pyage.core.agent.agent import AGENT
 import signal
 
 logger = logging.getLogger(__name__)
 
+try:
+    from Pyro4 import locateNS
+except:
+    print "Pyro4 not installed, running in local mode only"
+
 WORKPLACE = "workplace"
 
+
 class Workplace(Addressable):
     @Inject("agents:_Workplace__agents", "migration", "stop_condition", "stats")
     @InjectOptional("ns_hostname", "daemon")
